==> nattable_1.6.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-1.6.0/org.eclipse.nebula.widgets.nattable.dataset/src/org/eclipse/nebula/widgets/nattable/dataset/NumberValues.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2013, 2015 Original authors and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.dataset;

public class NumberValues {
    private int columnOneNumber;
    private int columnTwoNumber;
    private int columnThreeNumber;
    private int columnFourNumber;
    private int columnFiveNumber;
    private int columnSixNumber;
    private int columnSevenNumber;
    private int columnEightNumber;
    private int columnNineNumber;
    private int columnTenNumber;

    public NumberValues() {}

    public int getColumnOneNumber() {
        return this.columnOneNumber;
    }

    public void setColumnOneNumber(int columnOneNumber) {
        this.columnOneNumber = columnOneNumber;
    }

    public int getColumnTwoNumber() {
        return this.columnTwoNumber;
    }

    public void setColumnTwoNumber(int columnTwoNumber) {
        this.columnTwoNumber = columnTwoNumber;
    }

    public int getColumnThreeNumber() {
        return this.columnThreeNumber;
    }

    public void setColumnThreeNumber(int columnThreeNumber) {
        this.columnThreeNumber = columnThreeNumber;
    }

    public int getColumnFourNumber() {
        return this.columnFourNumber;
    }

    public void setColumnFourNumber(int columnFourNumber) {
        this.columnFourNumber = columnFourNumber;
    }

    public int getColumnFiveNumber() {
        return this.columnFiveNumber;
    }

    public void setColumnFiveNumber(int columnFiveNumber) {
        this.columnFiveNumber = columnFiveNumber;
    }

    public int getColumnSixNumber() {
        return this.columnSixNumber;
    }

    public void setColumnSixNumber(int columnSixNumber) {
        this.columnSixNumber = columnSixNumber;
    }

    public int getColumnSevenNumber() {
        return this.columnSevenNumber;
    }

    public void setColumnSevenNumber(int columnSevenNumber) {
        this.columnSevenNumber = columnSevenNumber;
    }

    public int getColumnEightNumber() {
        return this.columnEightNumber;
    }

    public void setColumnEightNumber(int columnEightNumber) {
        this.columnEightNumber = columnEightNumber;
    }

    public int getColumnNineNumber() {
        return this.columnNineNumber;
    }

    public void setColumnNineNumber(int columnNineNumber) {
        this.columnNineNumber = columnNineNumber;
    }

    public int getColumnTenNumber() {
        return this.columnTenNumber;
    }

    public void setColumnTenNumber(int columnTenNumber) {
        this.columnTenNumber = columnTenNumber;
    }
}

==> nattable_2.0.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-2.0.0/org.eclipse.nebula.widgets.nattable.dataset/src/org/eclipse/nebula/widgets/nattable/dataset/NumberValues.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2020 Original authors and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.dataset;

public class NumberValues {
    private int columnOneNumber;
    private int columnTwoNumber;
    private int columnThreeNumber;
    private int columnFourNumber;
    private int columnFiveNumber;
    private int columnSixNumber;
    private int columnSevenNumber;
    private int columnEightNumber;
    private int columnNineNumber;
    private int columnTenNumber;

    public NumberValues() {
    }

    public int getColumnOneNumber() {
        return this.columnOneNumber;
    }

    public void setColumnOneNumber(int columnOneNumber) {
        this.columnOneNumber = columnOneNumber;
    }

    public int getColumnTwoNumber() {
        return this.columnTwoNumber;
    }

    public void setColumnTwoNumber(int columnTwoNumber) {
        this.columnTwoNumber = columnTwoNumber;
    }

    public int getColumnThreeNumber() {
        return this.columnThreeNumber;
    }

    public void setColumnThreeNumber(int columnThreeNumber) {
        this.columnThreeNumber = columnThreeNumber;
    }

    public int getColumnFourNumber() {
        return this.columnFourNumber;
    }

    public void setColumnFourNumber(int columnFourNumber) {
        this.columnFourNumber = columnFourNumber;
    }

    public int getColumnFiveNumber() {
        return this.columnFiveNumber;
    }

    public void setColumnFiveNumber(int columnFiveNumber) {
        this.columnFiveNumber = columnFiveNumber;
    }

    public int getColumnSixNumber() {
        return this.columnSixNumber;
    }

    public void setColumnSixNumber(int columnSixNumber) {
        this.columnSixNumber = columnSixNumber;
    }

    public int getColumnSevenNumber() {
        return this.columnSevenNumber;
    }

    public void setColumnSevenNumber(int columnSevenNumber) {
        this.columnSevenNumber = columnSevenNumber;
    }

    public int getColumnEightNumber() {
        return this.columnEightNumber;
    }

    public void setColumnEightNumber(int columnEightNumber) {
        this.columnEightNumber = columnEightNumber;
    }

    public int getColumnNineNumber() {
        return this.columnNineNumber;
    }

    public void setColumnNineNumber(int columnNineNumber) {
        this.columnNineNumber = columnNineNumber;
    }

    public int getColumnTenNumber() {
        return this.columnTenNumber;
    }

    public void setColumnTenNumber(int columnTenNumber) {
        this.columnTenNumber = columnTenNumber;
    }
}
